##  Notification Channels
The following notification channels are available:
  * Email: This is the primary channel for notifications. You can adjust your email notification preferences on the Email tab of the Notifications page.
  * Microsoft Teams: If the integration with Microsoft Teams is configured for your workspace, you can install this app to receive notifications there. After installation, you can adjust your notification preferences on the Microsoft Teams tab of the Notifications page. To learn more, see [SAP LeanIX App for Microsoft Teams](https://help.sap.com/docs/leanix/ea/sap-leanix-app-for-microsoft-teams?locale=en-US&state=PRODUCTION&version=CLOUD "Setting up the SAP LeanIX App for Microsoft Teams").
